# PyJanggi
PyJanggi is a Python library for a Korean chess called [Janggi](https://en.wikipedia.org/wiki/Janggi).
It provides functionalities to simulate a game, maintain a game board, list all possible moves, make a move, and validate a move.

## Documentation
Check out the [GitHub Page](https://sungho-cho.github.io/pyjanggi/) for package documentation.

## Getting Started
PyJanggi is originally designed to be imported by other packages and provide Janggi game logic and classes, but if you want to check if the PyJanggi package is working, you can follow these steps:

1. Clone the repository

    `git clone https://github.com/sungho-cho/pyjanggi.git`

2. Install dependencies

    `pip install -r requirements.txt`

3. Run `main.py`

    `python janggi/main.py`

    If you see the UI window and can navigate with left and right arrow keys, your PyJanggi package is working!

## Releases
Check out the [PyPi Package](https://pypi.org/project/janggi) for releases

## License
[MIT License](LICENSE)
